@@ -476,7 +476,7 @@ EOF
                 "$path/$_->[0]/" );
         }
     }
-    buildPackageLock( $dir, "$path/pkgjs-lock.json", 1 );
+    buildPackageLock( $dir, "$path/pkgjs-lock.json", 1, $self->get_parallel );
 }
 
 sub filesFieldToList {
@@ -782,7 +782,7 @@ EOT
             addsubstvar( $pkg, 'nodejs:Provides', join( ', ', @provides ) );
         }
     }
-    if ( my $_builtUsing = builtUsing() ) {
+    if ( my $_builtUsing = builtUsing( $self->get_parallel ) ) {
         foreach my $pkg (@pkgs) {
             addsubstvar( $pkg, 'nodejs:BuiltUsing', $_builtUsing );
         }
